<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Zavrieť (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Zbaliť</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Rozbaliť</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Zrušiť upozornenie</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln slov</numerusform>
            <numerusform>%Ln slov</numerusform>
            <numerusform>%Ln slov</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minút(y)</numerusform>
            <numerusform>%Ln minút(y)</numerusform>
            <numerusform>%Ln minút(y)</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Denný pokrok</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Najdlhší pás</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Aktuálny pás</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dní</numerusform>
            <numerusform>%n dní</numerusform>
            <numerusform>%n dní</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;mdash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Nastaviť jazyk</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Bez názvu %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Iba na čítanie)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Prepáčte</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Nedá sa uložiť &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Uložiť súbor ako</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Nedá sa prepísať &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Premenovať súbor</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Nedá sa premenovať  &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Opätovne načítať súbor?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Opätovne načítať súbor %1 z disku?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Všetky neuložené zmeny budú stratené.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Opätovne načítať</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Bez názvu %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Uloženie ako obyčajný text odstráni formátovanie. Chcete zrušiť formátovanie?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Súbor bol zmenený</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Súbor %1 bol zmenený iným programom.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Chcete súbor opätovne načítať?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Opätovne načítať</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovať</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Súbor bol vymazaný</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Súbor %1 bol vymazaný iným programom.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Chcete súbor uložiť alebo zavrieť?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nie je možné otvoriť archív.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Vyhľadať:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Nahradiť:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorovať veľkosť začiatočných písmen</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Iba celé slová</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Regulárne výrazy</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Hľadať smerom hore</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Hľadať smerom dole</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Nájsť</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>Na&amp;hradiť</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Nahradiť &amp;všetko</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Nájsť</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Nahradiť</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Nahradiť %n výskyt?</numerusform>
            <numerusform>Nahradiť %n výskyty?</numerusform>
            <numerusform>Nahradiť %n výskytov?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Prepáčte</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Výraz nebol nájdený.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Obyčajný text</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Všetky súbory</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Všetky podporované súbory</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Pridať</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Kontrola pravopisu...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Žiadne návrhy neboli nájdené)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Otvoriť obrázok</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Výber jazyka programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Predvolený jazyk systému&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>K zmene jazyka dôjde po reštarte programu. </translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nie je možné otvoriť archív.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Štatistika</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Panel nástrojov</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Kontrola pravopisu</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Výber slovníka</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Prepáčte</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Archív nie je možné otvoriť. </translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Archív neobsahuje použiteľný slovník. </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skratky</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Bol zistený konflikt jednej alebo viacerých skratiek. Chcete pokračovať?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Slovník &quot;%1&quot; už existuje. Chcete ho nahradiť?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Denný cieľ</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žiadny</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minút:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Slov:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Úpravy</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Vždy zarovnať vertikálne na stred</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Kurzor vkladania bloku</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Jemné písma</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Zvuk písacieho stroja</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Inteligentné úvodzovky:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dvojité</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Jednoduché</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scény</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Oddeľovač:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Ukladanie</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Zapamätať si pozíciu kurzora</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Počet slov</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Počet strán</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Počet odstavcov</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Počet znakov</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Znakov:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Odstavcov:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritmus počítania slov</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Vynulovať dnešný denný pokrok?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Napísať znak pre označenie poradia bajtov v obyčajných textových súboroch</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Nastavený formát:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Vynulovať dnešok</translation>
    </message>
    <message>
        <source>History</source>
        <translation>História</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Zapamätať históriu</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Ukázať pásy</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Najmenší progres pre pásy:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Rozoznávanie hraníc slov</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Deliť počet znakov šiestimi</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Počítať každé písmeno ako slovo</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritmus počítania strán</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Štýl</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Iba ikony</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Iba text</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Text vedľa ikon</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Text pod ikonami</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Pozícia textu:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Činnosti</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Posunúť nahor</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Posunúť nadol</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Pridať oddeľovač</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Príkaz</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Skratka</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Činnosť</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Kontrola pravopisu počas písania</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignorovať slová písané VEĽKÝMI PÍSMENAMI</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignorovať slová obsahujúce čísla</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridať</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrániť</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Osobný slovník</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Odstrániť aktuálny slovník?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Používateľské rozhranie</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation> Vždy ukazovať rolovací pruh</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Vždy ukazovať hornú lištu</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Vždy ukazovať spodnú lištu</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Nepodporovaný súbor RTF. </translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Neočakávaný koniec súboru. </translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Posunúť scény nahor</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Prepnúť zoznam scén</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Zobraziť zoznam scén (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Skryť zoznam scén (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Posunúť scény nadol</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Zmeniť veľkosť zoznamu scén</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Prednastavený</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Spravovať relácie</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>R&amp;elácie</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nová</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Kópia</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Zmazať</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Prepnúť na</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nová relácia</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplikovať reláciu</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Premenovať reláciu</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Vymazať vybranú reláciu?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Názov relácie:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Prepáčte</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Požadovaný názov relácie sa už používa.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nová...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Spravovať...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Obnoviť prednastavené</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Skratky:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Nahrádzanie úvodzoviek...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Čakajte prosím</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Kontrola pravopisu</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Pridať</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorovať</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnorovať všetko</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Zmeniť</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Z&amp;meniť všetko</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Nenachádza sa v slovníku:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Zmeniť na:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Kontrola pravopisu...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Čakajte prosím</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Pokračovať v kontrole od začiatku súboru?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Kontrola pravopisu ukončená. </translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Symboly</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Posledné použité symboly</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Všetky symboly</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Názov:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Vložiť</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Bloky</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skripty</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Bez názvu %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Názov:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Žiadny obrázok</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Dlaždice</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Na stred</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Roztiahnuť</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Zmenšiť</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Priblížiť</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Nepriehľadnosť:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Pozícia:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Šírka:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Oblé rohy pozadia textu</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Polomer:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Rozmazané pozadie textu</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Tieň pozadia textu</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Zvislý posun:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Okraje</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Okno:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Strana:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Odsadiť prvý riadok</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Nad:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Pod:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrániť</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Upraviť tému</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Pozadie okna</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farba:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Obrázok:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>pixelov</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Zarovnať vľavo</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Pozadie textu</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Zarovnať vpravo</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Písmo:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Chybne napísané:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Riadkovanie</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Jednoduché</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 riadka</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dvojité</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcionálne</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Odstupy medzi odstavcami</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Šírka zarážky:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nová téma</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Témy</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Prednastavený</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Nežné blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Stará škola</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Vesmírne sny</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Písací stôl</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Kópia</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Vlastný</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upraviť</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Zmazať</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importovať</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportovať</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Zmazať tému &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Témy (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importovať tému</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exportovať tému</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Zmazať časovač?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Slová:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Strany:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Odstavce:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Znaky:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Nastaviť oneskorenie</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Nastaviť čas</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Oneskorenie:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Čas:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Upozornenie:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Správa:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upraviť</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Zmazať</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nebežia žiadne časovače</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Časovače</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Posledný použitý</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Zrušiť úpravu časovačov?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Načítavanie tém</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Načítavanie zvukov</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otvoriť súbor</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>O programe FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Jednoduchý celoobrazovkový textový editor.</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Práva vyhradené &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydané pod licenciou &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Používa ikony zo sady ikon &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Použité pod licenciou &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Znaky: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Strany: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Odstavce: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Slová: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otváranie %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Bez názvu %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Vypísať všetky dokumenty</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Prepnúť na ďalší dokument</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Prepnúť na predchádzajúci dokument</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Prepnúť na prvý dokument</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Prepnúť na posledný dokument</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Prepnúť na dokument %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Načítavanie nastavení</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Nie je možné zapisovať do pohotovostnej vyrovnávacej pamäti.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozornenie</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>Program FocusWriter nebol riadne ukončený.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Obnoviť z vyrovnávacej pamäti. </translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Niektoré súbory nemohli byť otvorené.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Niektoré súbory boli otvorené iba na čítanie. </translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>Súbor &apos;%1&apos; je novší ako kópia vo vyrovnávacej pamäti.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Prepísať novší súbor?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Uložiť zmeny?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Uložiť zmeny do súboru &apos;%1&apos; pred zatvorením?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vaše zmeny budú stratené ak ich neuložíte.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nie je možné načítať zvuky písacieho stroja.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Súbor</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nový</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Otvoriť...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Opätovne &amp;načítať</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Uložiť</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Uložiť &amp;ako...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Premenovať...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>U&amp;ložiť všetko</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Spravovať relácie</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nová relácia</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Tlač...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavrieť</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>S&amp;končiť</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Upra&amp;viť</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Späť</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Opakovať</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Vys&amp;trihnúť</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovať</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepiť</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Prilepiť &amp;bez formátovania</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Vybrať &amp;všetko</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Vybrať &amp;scénu</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmátovanie</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Tu&amp;čné</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>K&amp;urzivá</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Po&amp;dčiarknuté</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Pr&amp;ečiarknuté</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Horný inde&amp;x</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Dolný i&amp;ndex</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Zarovnať &amp;vľavo</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Zarovnať na st&amp;red</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Zarovnať v&amp;pravo</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Zarovnať do bl&amp;oku</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Z&amp;menšiť odsadenie</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Z&amp;väčšiť odsadenie</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Bl&amp;ok zľava doprava</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>B&amp;lok sprava doľava</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Nástroje</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>Ná&amp;jsť...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Nájsť &amp;ďalší</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Nájsť &amp;predchádzajúci</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Na&amp;hradiť...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Inteligentné ú&amp;vodzovky</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Aktualizovať &amp;dokument</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Aktualizovať &amp;výber</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Pravopis...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Nastaviť &amp;jazyk...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>Čas&amp;ovače...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ymboly...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Denný pokrok</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavenia</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Zobraziť p&amp;anel nástrojov</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Zobraziť &amp;ikony ponuky</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Za&amp;meraný text</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimalizovať</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Témy...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Predvoľby...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Vypnúť zameranie</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Zamerať jeden riadok</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Zamerať tri riadky</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>O&amp;dstavec</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Zamerať odstavec</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápoveda</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Jazyk p&amp;rogramu...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Niektoré súbory neboli podporované a nemohli byť otvorené.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Vypnuté</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Jeden &amp;riadok</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tri riadky</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programe</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Nastavenie &amp;strany</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Nadpis</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Nadpis &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Nadpis &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Nadpis &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Nadpis &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Nadpis &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Nadpis &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>Normálny</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
